Description Usage Arguments Examples
This function finds admissible design realisations for single-arm binary outcome trials, using stochastic curtailment. This function differs from findDesigns in that it includes a Simon-style interim analysis after some n1 participants. The output is a data frame of admissible design realisations.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 |
nmin |
Minimum permitted sample size. |
nmax |
Maximum permitted sample size. |
alpha |
Significance level |
power |
Required power (1-beta). |
minthetaE |
Minimum value of upper threshold theta_E_min. Defaults to p. |
maxthetaF |
Maximum value of lower CP threshold theta_F_max. Defaults to p. |
bounds |
choose what final rejection boundaries should be searched over: Those of A'Hern ("ahern"), Wald ("wald") or no constraints (NA). Defaults to "wald". |
fixed.r1 |
Choose what interim rejection boundaries should be searched over. Useful for reproducing a particular design realisation. Defaults to NA. |
fixed.n1 |
Choose what interim sample size values n1 should be searched over. Useful for reproducing a particular design realisation. Defaults to NA. |
max.combns |
Provide a maximum number of ordered pairs (theta_F, theta_E). Defaults to 1e6. |
maxthetas |
Provide a maximum number of CP values used to create ordered pairs (theta_F, theta_E). Can be used instead of max.combns. Defaults to NA. |
exact.thetaF |
Provide an exact value for lower threshold theta_F. Useful for reproducing a particular design realisation. Defaults to NA. |
exact.thetaE |
Provide an exact value for upper threshold theta_E. Useful for reproducing a particular design realisation. Defaults to NA. |
1 | findSCdesigns(nmin = 20, nmax = 21, p0 = 0.1, p1 = 0.4, power = 0.8, alpha = 0.1, max.combns=1e2)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.